Flake8 translation.activate
===========================

Check for usages of translation.activate().

This module provides a plugin for ``flake8``, the Python code checker.


Installation
------------

You can install or upgrade ``flake8-translation-activate`` with these commands::

  $ pip install flake8-translation-activate
  $ pip install --upgrade flake8-translation-activate


Plugin for Flake8
-----------------

When both ``flake8`` and ``flake8-translation-activate`` are installed, the plugin is
available in ``flake8``::

    $ flake8 --version
    2.0 (pep8: 1.4.5, flake8-translation-activate: 1.0, pyflakes: 0.6.1)
